@@ -14,11 +14,10 @@ my $GEN = {map { ($_, *{"gen_$_"}{CODE}) } qw(gs gsch gs_value gsch_value gs_cod
 
 sub GEN : Export {$GEN}
 
-sub gen_new ($class, $opts) {
+sub gen_new ($opts) {
 
   sub {
-    my $obj   = shift;
-    my %attrs = @_;
+    my ($class, $obj, %attrs) = (shift, shift, @_);
     exists $attrs{$_} or croak qq#Attribute "$_" is required# for $opts->{required}->@*;
 
     foreach my $k (keys %attrs) {
@@ -106,7 +105,7 @@ Evo::Class::Gen::HUF
 
 =head1 VERSION
 
-version 0.0211
+version 0.0212
 
 =head1 AUTHOR
 
