@@ -9,11 +9,10 @@ my $GEN = {map { ($_, *{"gen_$_"}{CODE}) } qw(gs gsch gs_value gsch_value gs_cod
 
 sub GEN : Export {$GEN}
 
-sub gen_new ($_class, $opts) {
+sub gen_new ($opts) {
 
   sub {
-    my $class = @_ % 2 ? shift : $_class;
-    my %attrs = @_;
+    my ($class, %attrs) = (shift, @_);
     exists $attrs{$_} or croak qq#Attribute "$_" is required# for $opts->{required}->@*;
 
     foreach my $k (keys %attrs) {
@@ -100,7 +99,7 @@ Evo::Class::Gen::Hash
 
 =head1 VERSION
 
-version 0.0211
+version 0.0212
 
 =head1 AUTHOR
 
