@@ -11,7 +11,7 @@ sub new : Export {
 
 sub import ($me, @args) {
   my $caller = caller;
-  meta_of($caller) || meta_of($caller, Evo::Class::Meta::new(class => $caller));
+  meta_of($caller) || meta_of($caller, Evo::Class::Meta->new(class => $caller));
   export_install_in($caller, $me, @args ? @args : '*');
 }
 
@@ -29,7 +29,7 @@ Evo::Class::Role
 
 =head1 VERSION
 
-version 0.0211
+version 0.0212
 
 =head1 DESCRIPTION
 
@@ -61,7 +61,7 @@ Also can be used as "interaces"
   }
 
 
-  my $obj = My::Class::new();
+  my $obj = My::Class->new();
   say $obj->to_lc;    # value
 
   {
