@@ -22,7 +22,7 @@ Evo::Class::T
 
 =head1 VERSION
 
-version 0.0211
+version 0.0212
 
 =head1 DESCRIPTION
 
@@ -38,7 +38,7 @@ Types for L<Evo::Class/"check">. Right now there aren't so many of them.
 
   }
 
-  my $obj = My::Foo::new(status => "ok");
+  my $obj = My::Foo->new(status => "ok");
   $obj->status("badVal");    # dies
 
 =head1 FUNCTIONS
