@@ -61,7 +61,7 @@ Evo::Ee
 
 =head1 VERSION
 
-version 0.0211
+version 0.0212
 
 =head1 DESCRIPTION
 
@@ -83,7 +83,7 @@ EventEmitter role for Evo classes
 
   }
 
-  my $comp = My::Class::new();
+  my $comp = My::Class->new();
 
   # subscribe on the event
   $comp->on(connection => sub($self, $id) { say "got $id" });
