@@ -18,6 +18,7 @@ export_anon steady_time => $HAS_M_TIME
   : \&Time::HiRes::time;
 
 
+# combine higher order function without any protection and passing arguments
 sub ws_fn : Export {
   my $cb = pop or croak "Provide a function";
   return $cb unless @_;
@@ -25,6 +26,27 @@ sub ws_fn : Export {
   $cb;
 }
 
+# call each $next exactly once or die. Bypas args to cb
+sub combine_thunks : Export {
+
+  my $_cb = pop or croak "Provide a function";
+  return $_cb unless my @hooks = @_;
+
+  my @args;
+  my $cb = sub { $_cb->(@args) };
+
+  foreach my $cur (reverse @hooks) {
+    my $last  = $cb;
+    my $count = 0;
+    my $safe  = sub { $last->() unless $count++ };
+
+    $cb = sub { $cur->($safe); die "\$next in hook called $count times" unless $count == 1 };
+
+  }
+
+  sub { @args = @_; $cb->(); return };
+}
+
 
 1;
 
@@ -40,7 +62,7 @@ Evo::Lib
 
 =head1 VERSION
 
-version 0.0211
+version 0.0212
 
 =head1 AUTHOR
 
