@@ -2,7 +2,7 @@ package Evo::Loop;
 use Evo '-Export *';
 use Evo '::Class';
 
-our $SINGLE = Evo::Loop::Class::new();
+our $SINGLE = Evo::Loop::Class->new();
 
 sub loop_start : Export { $SINGLE->start(@_) }
 sub loop_stop : Export  { $SINGLE->stop(@_) }
@@ -18,7 +18,9 @@ sub loop_io_remove_out : Export { $SINGLE->io_remove_out(@_); }
 sub loop_io_remove_all : Export { $SINGLE->io_remove_all(@_); }
 sub loop_io_remove_fd : Export  { $SINGLE->io_remove_fd(@_); }
 
-sub loop_zone : Export                    { $SINGLE->zone(@_) }
+sub loop_zone : prototype(&) : Export     { $SINGLE->zone(@_) }
+sub loop_zone_level : Export              { $SINGLE->zone_level(@_) }
+sub loop_zone_escape : Export             { $SINGLE->zone_escape(@_) }
 sub loop_zone_middleware : Export         { $SINGLE->zone_middleware(@_) }
 sub loop_postpone : prototype(&) : Export { $SINGLE->postpone(@_) }
 
@@ -36,7 +38,7 @@ Evo::Loop
 
 =head1 VERSION
 
-version 0.0211
+version 0.0212
 
 =head1 AUTHOR
 
