@@ -29,13 +29,13 @@ Evo::Net::Srv
 
 =head1 VERSION
 
-version 0.0211
+version 0.0212
 
 =head1 SYNOPSYS
 
   use Evo '-Net::Srv; -Loop *';
 
-  my $srv = Evo::Net::Srv::new();
+  my $srv = Evo::Net::Srv->new();
   my $listen_socket = $srv->srv_listen(ip => '*', port => 8080);
 
   $srv->on(
